[![Build status](https://ci.appveyor.com/api/projects/status/g2q9140ejkt92b6m/branch/develop?retina=true)](https://ci.appveyor.com/project/support-dataclay/pyclay/branch/develop)
[![Build status](https://ci.appveyor.com/api/projects/status/g2q9140ejkt92b6m/branch/develop?svg=true&passingText=Passing+functional+tests&pendingText=Building+functional+tests)](https://dataclay.bsc.es/testing-report/)

[![Documentation Status](https://readthedocs.org/projects/pyclay/badge/?version=latest)](https://pyclay.readthedocs.io/en/latest/?badge=latest)
![PyPI - Status](https://img.shields.io/pypi/status/dataclay)
![PyPI - Format](https://img.shields.io/pypi/format/dataclay)
[![License](https://img.shields.io/github/license/bsc-dom/pyclay)](https://github.com/bsc-dom/pyclay/blob/develop/LICENSE.txt)
[![PyPI version](https://badge.fury.io/py/dataClay.png)](https://badge.fury.io/py/dataClay)
[![Pypi Downloads](https://pepy.tech/badge/dataclay)](https://pepy.tech/project/dataclay)
<br/>

[![Test Pypi](https://img.shields.io/badge/testpypi-2.7.dev-green)](https://test.pypi.org/project/dataClay/)

# dataClay Python codebase

This repository holds the `pyclay` Python package. This package is used both
by the dataClay Python clients and also for the dataClay service Execution
Environment.

## Installation

This package is available from PyPI, so just `pip` it:

    $ pip install dataClay

## Documentation

Official documentation available at [read the docs](https://pyclay.readthedocs.io/en/latest/)

## Other resources

[BSC official dataClay webpage](https://www.bsc.es/dataclay)

---

![dataClay logo](https://www.bsc.es/sites/default/files/public/styles/bscw2_-_simple_crop_style/public/bscw2/content/software-app/logo/logo_dataclay_web_bsc.jpg)
